@@ -23,6 +23,15 @@
 
 #define IMAGE_HEIGHT 400
 
-#define GAME_VERSION = "0.1"
+#define GAME_VERSION 0.3
+
+#define EASY_PIECE_COUNT 9
+#define EASY_HORIZONTAL_COUNT 3
+#define HARD_PIECE_COUNT 16
+#define HARD_HORIZONTAL_COUNT 4
+
+#define DEFAULT_IMAGE_TXT "Default image"
+#define RANDOM_IMAGE_TXT "Random image"
+#define SELECT_IMAGE_TXT "Select image..."
 
 #endif // DEFINES_H
